// Copyright (c) 2006, Gregory Todd <greg@oddsim.com>
//
// Permission to use, copy, modify, and/or distribute this software for any
// purpose with or without fee is hereby granted, provided that the above
// copyright notice and this permission notice appear in all copies.
// 
// THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
// WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
// MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
// ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
// WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
// ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
// OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.

using System;
using System.Collections.Generic;
using System.Text;

namespace Othello.Engine
{
    public class Move : IComparable<Move>
    {
        private static Random rand = new Random();

        public static readonly Move Empty = new Move(-1, -1, -1);

        public int x;
        public int y;
        int value;
        double random;

        public Move(int x, int y, int value)
        {
            this.x = x;
            this.y = y;
            this.value = value;
            this.random = rand.NextDouble();
        }

        public override string ToString()
        {
            return String.Format("<{0}, {1}>, {2}", x, y, value);
        }

        #region IComparable<Move> Members

        public int CompareTo(Move other)
        {
            if (other == this)
                return 0;
            if (other.value - this.value != 0)
                return other.value - this.value;
            if (other.random > this.random)
                return 1;
            else
                return -1;
        }

        #endregion
    }
}
